bayespy.inference.vmp.transformations.RotateGaussianMarkovChain.nodes
=====================================================================

.. currentmodule:: bayespy.inference.vmp.transformations

.. automethod:: RotateGaussianMarkovChain.nodes